==> haskell-lifted-base-0.2.3.12-291-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lifted-base
version:              0.2.3.12
visibility:           public
id:                   lifted-base-0.2.3.12-EX9KK5L0YZb8kuGGqSzr5f
key:                  lifted-base-0.2.3.12-EX9KK5L0YZb8kuGGqSzr5f
license:              BSD-3-Clause
copyright:            (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk, Anders Kaseorg
homepage:             https://github.com/basvandijk/lifted-base
synopsis:             lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.

    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.

category:             Control
abi:                  e5ffd931d6adc77058bfe684d0baf642
exposed:              True
exposed-modules:
    Control.Concurrent.Chan.Lifted Control.Concurrent.Lifted
    Control.Concurrent.MVar.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Exception.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lifted-base-0.2.3.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lifted-base-0.2.3.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lifted-base-0.2.3.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-base
hs-libraries:         HSlifted-base-0.2.3.12-EX9KK5L0YZb8kuGGqSzr5f
includes:             inlinable.h
depends:
    base-4.17.2.1 monad-control-1.0.3.1-DSKGk7hVXWfFdb7q3Orv7L
    transformers-base-0.4.6-CLSmRvqNTF5Lcd4OvY3BYQ

haddock-interfaces:   /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html:         /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lifted-base-0.2.3.12-292-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lifted-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lifted-base
version:              0.2.3.12
visibility:           public
id:                   lifted-base-0.2.3.12-L2N6U9lxrMyAkZgo4dcBxa
key:                  lifted-base-0.2.3.12-L2N6U9lxrMyAkZgo4dcBxa
license:              BSD-3-Clause
copyright:            (c) 2011-2012 Bas van Dijk, Anders Kaseorg
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk, Anders Kaseorg
homepage:             https://github.com/basvandijk/lifted-base
synopsis:             lifted IO operations from the base library
description:
    @lifted-base@ exports IO operations from the base library lifted to
    any instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

    Note that not all modules from @base@ are converted yet. If
    you need a lifted version of a function from @base@, just
    ask me to add it or send me a patch.

    The package includes a copy of the @monad-peel@ testsuite written
    by Anders Kaseorg The tests can be performed using @cabal test@.

category:             Control
abi:                  ec1ac2009a54ae340da67a25f96cf5ea
exposed:              True
exposed-modules:
    Control.Concurrent.Chan.Lifted Control.Concurrent.Lifted
    Control.Concurrent.MVar.Lifted Control.Concurrent.QSem.Lifted
    Control.Concurrent.QSemN.Lifted Control.Exception.Lifted
    Data.IORef.Lifted Foreign.Marshal.Utils.Lifted
    System.Timeout.Lifted

import-dirs:          /usr/lib/ghc-9.4.8/site-local/lifted-base-0.2.3.12
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lifted-base-0.2.3.12
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lifted-base-0.2.3.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lifted-base
hs-libraries:         HSlifted-base-0.2.3.12-L2N6U9lxrMyAkZgo4dcBxa
includes:             inlinable.h
depends:
    base-4.17.2.1 monad-control-1.0.3.1-Eri4AwhrtCa8G52kkUFfeD
    transformers-base-0.4.6-9gqoIpeYmGjDLnucKUpqef

haddock-interfaces:   /usr/share/doc/haskell-lifted-base/html/lifted-base.haddock
haddock-html:         /usr/share/doc/haskell-lifted-base/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
